import ggetrs

def test_ucsc_blat_example_dna():
    sequence = "AGTGGTACATGCAGTTTGATGATGATGAGAAACAGAAGCT"
    response = ggetrs.ucsc.blat(sequence)
    assert(len(response) == 3)
    assert(response[0]["matches"] == 40)

def test_ucsc_blat_example_protein():
    sequence = "MIRFILIQNRAGKTRLAKWYMQFDDDEKQK"
    response = ggetrs.ucsc.blat(sequence, "protein")
    assert(len(response) == 1)
    assert(response[0]["matches"] == 29)

def test_ucsc_blat_missing_db():
    sequence = "AGTGGTACATGCAGTTTGATGATGATGAGAAACAGAAGCT"
    response = ggetrs.ucsc.blat(sequence, db_name="blahblahblah")
    assert(len(response) == 3)
    assert(response[0]["matches"] == 40)

def test_ucsc_blat_example_wrong_seqtype():
    sequence = "MIRFILIQNRAGKTRLAKWYMQFDDDEKQK"
    try:
        response = ggetrs.ucsc.blat(sequence, "dna")
        assert(False)
    except:
        assert(True)



import ggetrs
import requests
ENSEMBL_RELEASE = 109

def ping_ensembl_ftp():
    try:
        requests.head("https://ftp.ensembl.org", timeout = 5)
        return True
    except:
        # ensembl ftp server is down; skip check
        return False

def test_search_toplevel():
    search_terms = ["AP2S1"]
    results = ggetrs.search(search_terms)
    assert("results" in results.keys())
    assert(len(results["results"]) == 1)
    assert("display_label" in results["results"][0].keys())
    assert(results["results"][0]["display_label"] == "AP2S1")

def test_search_module():
    search_terms = ["AP2S1"]
    results = ggetrs.ensembl.search(search_terms)
    assert("results" in results.keys())
    assert(len(results["results"]) == 1)
    assert("display_label" in results["results"][0].keys())
    assert(results["results"][0]["display_label"] == "AP2S1")

def test_database_nofilter():
    results = ggetrs.ensembl.database()
    assert(isinstance(results, list))
    assert(len(results) > 1)

def test_database_filter():
    if ping_ensembl_ftp():
        results = ggetrs.ensembl.database(f"homo_sapiens_core_{ENSEMBL_RELEASE}_38")
        assert(isinstance(results, list))
        assert(len(results) == 1)
        assert(results[0] == f"homo_sapiens_core_{ENSEMBL_RELEASE}_38")

def test_release():
    results = ggetrs.ensembl.release()
    assert(results == ENSEMBL_RELEASE)

def test_reference():
    if ping_ensembl_ftp():
        results = ggetrs.ensembl.reference(datatype=["dna"])
        assert(isinstance(results, list))
        assert(len(results) == 1)
        assert(isinstance(results[0], dict))
        assert(results[0]["url"] == f"http://ftp.ensembl.org/pub/release-{ENSEMBL_RELEASE}/fasta/homo_sapiens/dna/Homo_sapiens.GRCh38.dna.primary_assembly.fa.gz")

def test_species():
    if ping_ensembl_ftp():
        results = ggetrs.ensembl.species()
        assert(isinstance(results, list))
        assert(len(results) > 1)
        assert("homo_sapiens" in results)



import ggetrs

def test_seq_dna():
    gene = "AP2S1"
    result = ggetrs.seq([gene])
    assert(len(result) == 1)
    assert(len(result[0].keys()) == 2)
    assert(result[0]["header"] == "ENSG00000042753 chromosome:GRCh38:19:46838136:46850846:-1")
    assert("GGGCCCTACAACTGCACCCTGAGCCGGAGCTGCCCAGTCGCCGCGGGACCGGGGCCGCTGGGGTCTGGACGGGGGTCGCCATGGTAACGGGGGAGCGCTACGCCGGGGACTGGCGGAGGG" in result[0]["sequence"])

def test_seq_protein():
    gene = "AP2S1"
    result = ggetrs.seq([gene], translate=True)
    assert(len(result) == 1)
    assert(len(result[0].keys()) == 2)
    assert(result[0]["header"] == "sp|P53680|AP2S1_HUMAN AP-2 complex subunit sigma OS=Human OX=9606 [GN=AP2S1 ] PE=1 SV=2")
    assert("MIRFILIQNRAGKTRLAKWYMQFDDDEKQKLIEEVHAVVTVRDAKHTNFVEFRNFKIIYRRYAGLYFCICVDVNDNNLAYLEAIHNFVEVLNEYFHNVCELDLVFNFYKVYTVVDEMFLAGEIRETSQTKVLKQLLMLQSLE" == result[0]["sequence"])

def test_seq_multiple():
    genes = ["AP2S1", "RFX3", "NSD1"]
    result = ggetrs.seq(genes)
    assert(len(result) == len(genes))
    assert(len(result[0].keys()) == 2)
    assert(len(result[1].keys()) == 2)
    assert(len(result[2].keys()) == 2)

def test_seq_nolist():
    genes = "AP2S1"
    try:
        ggetrs.seq(genes)
        assert(False)
    except:
        assert(True)



import ggetrs

def test_info_single():
    genes = ["AP2S1"]
    results = ggetrs.info(genes)
    assert(len(results.keys()) == 1)
    assert(genes[0] in results.keys())
    assert(results[genes[0]]["pdb_id"] == "6URI")

def test_info_multi():
    genes = ["AP2S1", "NSD1", "RFX3"]
    results = ggetrs.info(genes)
    assert(len(results.keys()) == 3)
    for g in genes:
        assert(g in results.keys())

def test_info_nolist():
    genes = "AP2S1"
    try:
        ggetrs.info(genes)
        assert(False)
    except:
        assert(True)



import ggetrs

def test_archs4_correlation():
    gene = "AP2S1"
    results = ggetrs.archs4.correlate(gene, 5)
    assert(type(results) == dict)
    assert("correlations" in results.keys())
    assert(len(results["correlations"]) == 5)

def test_archs4_tissue():
    gene = "AP2S1"
    results = ggetrs.archs4.tissue(gene, "human")
    assert(type(results) == dict)
    assert("tissues" in results.keys())
    assert(len(results["tissues"]) > 0)




import ggetrs

def test_enrichr():
    library = "GO_Biological_Process_2021"
    genes = ["AP2S1", "NSD1", "RFX3"]
    results = ggetrs.enrichr(library, genes)
    assert(type(results) == dict)
    assert(library in results.keys())

